# engineering_tools

A small Python module with common engineering utilities like acceleration, gear ratios, pressure.

Still under development!

TOOLS:

Acceleration Calculator
Pressure Calculator
Gear Ratio Calculator
Circuit Resistance Calculator
Torque Calculator

INSTALLATION:

Install the module using 'pip install engineering'. Then, import it inside your Python project using 'import engineering'.

ACCELERATION CALCULATOR:

Takes in force and mass and returns a float.

PRESSURE CALCULATOR:

Takes in force and area and returns a float.

GEAR RATIO CALCULATOR:

Takes in input and output gear teeth and returns a float.

CIRCUIT RESISTANCE CALCULATOR:

Takes in voltage and current and returns a float.

TORQUE CALCULATOR:

Takes in force and distance and returns a float.